Learn R Programming

door (version 0.0.2)

inv_tanh_ci: Calculate confidence interval of DOOR probability based on inverse hyperbolic tangent transformation of Wald-type CI

Description

Calculate confidence interval of DOOR probability based on inverse hyperbolic tangent transformation of Wald-type CI

Usage

inv_tanh_ci(
  y1 = NULL,
  y2 = NULL,
  n1 = NULL,
  n2 = NULL,
  data_type = c("freq", "prop"),
  summary_obj = NULL,
  conf_level = 0.95
)

Value

Inverse hyperbolic tangent transformation CI

Arguments

y1, y2

Numeric vectors of DOOR proportion or frequency distribution for group 1, group 2. The entries should be ordered from most desirable to least desirable

n1, n2

Sample sizes of group 1, group 2; must be specified if method = "prop"

data_type

Either "freq" for frequency input or "prop" for proportion input when using y1 and y2

summary_obj

A object returned by individual_to_summary(); Alternative input for y1 and y2

conf_level

Confidence level

See Also

door_ci()

Examples

Run this code
inv_tanh_ci(c(60,30,10), c(50,40,10))

Run the code above in your browser using DataLab